<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="si">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="27"/>
        <source>About</source>
        <translation>පිළිබඳව</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="30"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="31"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Context menu option explanation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="40"/>
        <source>Make window stay on top of all other windows.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="43"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="54"/>
        <source>Version: %1</source>
        <translation>අනුවාදය: %1</translation>
    </message>
    <message>
        <source>Copyright (c) 2020 %1</source>
        <translation type="vanished">ප්‍රකාශන හිමිකම (ඇ) 2020 %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="60"/>
        <source>Logo designed by %1</source>
        <translation>ලාංඡනය %1 විසින් නිර්මාණය කරන ලදි</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="62"/>
        <source>Built with Qt %1 (%2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Source code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="73"/>
        <source>Contributors</source>
        <translation>සහදායකයින්</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="75"/>
        <source>List of contributors on GitHub</source>
        <translation>ගිට්හබ් හි සහදායකයින්ගේ ලැයිස්තුව</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="76"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>මෙම ව්යාපෘතියට දායක වූ සියලු දෙනාටම ස්තූතියි.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="80"/>
        <source>Translators</source>
        <translation>පරිවර්තකයින්</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>මෙම යෙදුම පරිවර්තනය කිරීමට ස්වේච්ඡාවෙන් ඉදිරිපත් වූ පහත සඳහන් පුද්ගලයින්ට මම ස්තූතිවන්ත වෙමි.</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="125"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="149"/>
        <source>&amp;Special Thanks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="151"/>
        <source>&amp;Third-party Libraries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>Your Rights</source>
        <translation>ඔබගේ අයිතිවාසිකම්</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="46"/>
        <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="57"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="89"/>
        <source>%1 is released under the MIT License.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="90"/>
        <source>This license grants people a number of freedoms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="91"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>ඕනෑම කටයුත්තක් සඳහා %1 භාවිතා කිරීමට ඔබට නිදහස තිබේ</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="92"/>
        <source>You are free to distribute %1</source>
        <translation>%1 බෙදා හැරීමට ඔබට නිදහස තිබේ</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>You can study how %1 works and change it</source>
        <translation>%1 ක්‍රියා කරන ආකාරය අධ්‍යයනය කර එය වෙනස් කළ හැකිය</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="94"/>
        <source>You can distribute changed versions of %1</source>
        <translation>%1 හි වෙනස් කළ අනුවාදයන් ඔබට බෙදා හැරීමට හැකිය</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="96"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="124"/>
        <source>Third-party Libraries used by %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="147"/>
        <source>&amp;Help</source>
        <translation>උපකාර</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="148"/>
        <source>&amp;About</source>
        <translation>පිළිබඳව</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="150"/>
        <source>&amp;License</source>
        <translation>&amp;බලපත්‍රය</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../graphicsscene.cpp" line="89"/>
        <source>Drag image here</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <location filename="../graphicsview.cpp" line="351"/>
        <source>File url list is empty</source>
        <translation type="unfinished">ගොනු ඒ.ස.නි. (url) ලැයිස්තුව හිස් ය</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="52"/>
        <source>File is not a valid image</source>
        <translation>ගොනුව වලංගු නොවන රූපයකි</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="57"/>
        <location filename="../graphicsview.cpp" line="62"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="359"/>
        <source>Image data is invalid</source>
        <translation>රූපයේ දත්ත වලංගු නොවේ</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="366"/>
        <source>Not supported mimedata: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>File url list is empty</source>
        <translation>ගොනු ඒ.ස.නි. (url) ලැයිස්තුව හිස් ය</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>&amp;Copy</source>
        <translation>&amp;පිටපත්</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="39"/>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Stay on top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <location filename="../actionmanager.cpp" line="107"/>
        <source>Protected mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="45"/>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>Keep transformation</source>
        <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="92"/>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="93"/>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Flip &amp;Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Copy P&amp;ixmap</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="104"/>
        <source>Copy &amp;File Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="94"/>
        <source>Toggle Checkerboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="88"/>
        <source>&amp;Open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="90"/>
        <source>Actual size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="91"/>
        <source>Toggle maximize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="95"/>
        <source>Rotate right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Previous image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="98"/>
        <source>Next image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="109"/>
        <source>Configure...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="110"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="113"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="119"/>
        <source>Show in directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="121"/>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="122"/>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="41"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>පින්තූරය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>ගොනුව</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="33"/>
        <source>%1 File</source>
        <translation>ගොනු %1</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="40"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>විස්තරය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="50"/>
        <source>Dimensions</source>
        <translation>මාන</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Aspect ratio</source>
        <translation>දර්ශන අනුපාතය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="56"/>
        <source>Frame count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="60"/>
        <source>Name</source>
        <translation>නම</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Item type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Folder path</source>
        <translation>ගොනුවේ මාර්ගය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Size</source>
        <translation>ප්‍රමාණය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Date created</source>
        <translation>සෑදූ දිනය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date modified</source>
        <translation>වෙනස් කළ දිනය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="77"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Subject</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Rating</source>
        <translation>ශ්‍රේණිගත කිරීම</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Comments</source>
        <translation>අදහස්</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="88"/>
        <source>Authors</source>
        <translation>කතුවරුන්</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Date taken</source>
        <translation>ගත් දිනය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="96"/>
        <source>Program name</source>
        <translation>වැඩසටහනේ නම</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="101"/>
        <source>Horizontal resolution</source>
        <translation>තිරස් විභේදනය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Vertical resolution</source>
        <translation>සිරස් විභේදනය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Resolution unit</source>
        <translation>විභේදන ඒකකය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Colour representation</source>
        <translation>වර්ණ නිරූපණය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="110"/>
        <source>Camera maker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera model</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>F-stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>Exposure time</source>
        <translation>නිරාවරණ කාලය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>ISO speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>Exposure bias</source>
        <translation>නිරාවරණ නැඹුරුව</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Focal length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Max aperture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Metering mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Subject distance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Flash mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>35mm focal length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="135"/>
        <source>Lens model</source>
        <translation>කාච ආකෘතිය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Contrast</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Brightness</source>
        <translation>දීප්තිය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Exposure program</source>
        <translation>නිරාවරණ වැඩසටහන</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Saturation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Sharpness</source>
        <translation>තියුණු බව</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>White balance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>Digital zoom</source>
        <translation>සංඛ්‍යාංක විශාලනය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>EXIF version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="154"/>
        <source>Latitude reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude</source>
        <translation>අක්ෂාංශ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Longitude reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude</source>
        <translation>දේශාංශ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Altitude reference</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude</source>
        <translation>උන්නතාංශය</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="174"/>
        <source>%1 x %2</source>
        <translation>%1 x %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="192"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="317"/>
        <source>Property</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="317"/>
        <source>Value</source>
        <translation>අගය</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="22"/>
        <source>Settings</source>
        <translation>සැකසුම්</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="27"/>
        <source>Do nothing</source>
        <translation>කිසිවක් නොකරන්න</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="28"/>
        <source>Close the window</source>
        <translation>කවුළුව වහන්න</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="29"/>
        <source>Toggle maximize</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>Zoom in and out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>View next or previous item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Auto size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Maximized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Round (Integer scaling)</source>
        <comment>This option means round up for .5 and above</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Ceil (Integer scaling)</source>
        <comment>This option means always round up</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Floor (Integer scaling)</source>
        <comment>This option means always round down</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Follow system (Fractional scaling)</source>
        <comment>This option means don&apos;t round</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="69"/>
        <source>Stay on top when start-up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Double-click behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Mouse wheel behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="72"/>
        <source>Default window size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="73"/>
        <source>HiDPI scale factor rounding policy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="41"/>
        <source>Pineapple Pictures</source>
        <translation>පයින්ඇපල් පික්චර්ස්</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>File list.</source>
        <translation>ගොනු ලැයිස්තුව.</translation>
    </message>
</context>
</TS>
